@@ -47,7 +47,7 @@ def assert_files(directory, expected_files, check_contents=False):
 
             if check_contents and relative_file_path in expected_relative_files:
                 with open(os.path.join(start, relative_file_path), 'r', encoding='utf-8') as f:
-                    assert f.read() == expected_relative_files[relative_file_path]
+                    assert f.read() == expected_relative_files[relative_file_path], relative_file_path
 
     expected_relative_file_paths = set(expected_relative_files)
 
